// Listener to handle messages from the popup
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.action === "startScraping") {
        let maxPages = parseInt(message.maxPages, 10);
        scrapePages(maxPages);
    }
});

function scrapePages(maxPages) {
    for (let pageNumber = 1; pageNumber <= maxPages; pageNumber++) {
        let pageURL = "http://witchschool.com/lesson_detail/" + pageNumber;
        
        // Loop to handle multiple pages for each lesson (page=1, page=2, ..., page=20)
        for (let pagePart = 1; pagePart <= 20; pagePart++) {
            let urlWithPageParam = `${pageURL}?page=${pagePart}`;
            console.log("Fetching:", urlWithPageParam);

            fetch(urlWithPageParam, { credentials: "include" })
                .then(response => response.text())
                .then(html => {
                    let doc = new DOMParser().parseFromString(html, "text/html");
                    let lessonContent = doc.querySelector(".container");

                    if (lessonContent) {
                        let plainText = htmlToPlainText(lessonContent.innerHTML);
                        console.log(`Extracted Text from page ${pagePart}:`, plainText);

                        // Create a Blob from the plain text and save it as a .txt file
                        let blob = new Blob([plainText], { type: 'text/plain' });
                        let url = URL.createObjectURL(blob);
                        let a = document.createElement('a');
                        a.href = url;
                        a.download = `lesson_${pageNumber}_page_${pagePart}.txt`;  // Save as separate file for each page
                        a.click();  // Trigger the download
                        URL.revokeObjectURL(url);  // Clean up the URL object
                    } else {
                        console.error(`Failed to find lesson content on page ${pagePart}.`);
                    }
                })
                .catch(error => console.error(`Scraping error on page ${pagePart}:`, error));
        }
    }
}

function htmlToPlainText(html) {
    let doc = new DOMParser().parseFromString(html, "text/html");
    return doc.body.textContent || "";
}
